##############################################################################
#
#  Setup script for the ESO Scisoft scientific software collection
#
#  This file should be sourced using the sh/ksh/bash dot "." command
#
#      . /scisoft/bin/Setup.bash
#
#  by all users of the software. They should be no need to do anything else.
#
#  If you encounter any problems, email scihelp@eso.org.
#
##############################################################################
#
#  Revision history
#
#  ??/11/2000 - kmaguire - created, based on Setup.csh
#  ??/01/2005 - sturolla - modified and cleaned up
#  07/06/2005 - ahuxley  - converted to .src with substitutable markers, 
#                          corrected eclipse and python root directory tests,
#                          stripped redundant curly braces and quotes, changed
#                          exits to returns.
#  04/05/2017 - aszostak - Generalised setting of GAG_EXEC_SYSTEM for different
#                          Fedora versions. (PIPE-7196)
#                          Fixed path to python shared libraries. (PIPE-6704)
#                          Correcting URLs in warning messages.
#  05/05/2017 - aszostak - Generalised setting of MIDAS version.
#  
##############################################################################

#
#  echo'ing in scp sessions not allowed, so use this function instead of
#  echo.
#

echo_if_tty() { [ ! -t 1 ] || echo "$1"; }

#
#  Before doing anything check the shell
#

if [ "X$SHELL" != X ] && [ `basename $SHELL` != bash ]; then
    echo_if_tty "please start a bash shell before setting up scisoft"
    #  Don't use exit! It can potentially log the user out!
    return -1
fi

#
#  Find out which arch we are running on
#

if [ `uname` != Linux ]; then
    echo_if_tty "unsupported architecture"
    #  Don't use exit! It can potentially log the user out!
    return -1
fi

#
#  Add the main Scisoft binaries to the command search path
#

if [ "X$PATH" != X ]; then
    export PATH=/scisoft/bin:$PATH
else
    export PATH=/scisoft/bin
fi

#
#  Add the main Scisoft libraries to the library search path
#

if [ "X$LD_LIBRARY_PATH" != X ]; then
    export LD_LIBRARY_PATH=/scisoft/lib:$LD_LIBRARY_PATH
else
    export LD_LIBRARY_PATH=/scisoft/lib
fi

#
#  Add the main Scisoft manual pages to the manual page search path
#

if [ "X$MANPATH" != X ]; then
    export MANPATH=/scisoft/man:$MANPATH
else
    export MANPATH=/scisoft/man:
fi

#
#  Add the Scisoft X application defaults directory to XUSERFILESEARCHPATH.
#

if [ "X$XUSERFILESEARCHPATH" != X ]; then
    export XUSERFILESEARCHPATH=/scisoft/lib/X11/app-defaults:$XUSERFILESEARCHPATH
else
    export XUSERFILESEARCHPATH=/scisoft/lib/X11/app-defaults
fi

#
#  IRAF related definitions
#

if [ -d /scisoft/share/iraf ]; then
    #  Note trailing slashes
    export iraf=/scisoft/share/iraf/iraf/
    export stsdas=/scisoft/share/iraf/extern/stsdas/
    export tables=/scisoft/share/iraf/extern/tables/
    if [ -f ${iraf}unix/hlib/irafuser.bash ]; then
        . ${iraf}unix/hlib/irafuser.bash
        #  The above script sets F77, which is quite naughty of it; 
        #  it can cause users' own compiles of totally unrelated software
        #  to fail.
        export F77_IRAF=$F77
        unset F77
    fi
    export IRAFARCH=linux64

    #  From: "Warren J. Hack" <hack@stsci.edu>
    #  To: Richard Hook <rhook@eso.org>
    #  CC: greenfield@stsci.edu
    #  Subject: Re: Greetings and a question
    #  
    #  Hello,
    #
    #  >I just had a funny problem on my new machine here and I thought I
    #  >would check if you had seen it before and had a simple answer. I have
    #  >a new Linux FC3 machine which has IRAF 2.12.2a (redhat). I also have
    #  >PyRAF 1.1.2 (2005Mar19)  and Python 2.4. The OS is
    #  >Fedora Core release 3 (Heidelberg). If I start the cl all seems well,
    #  >however, from Pyraf I get:
    #  >
    #  >--> imstat dev$pix
    #  >#               IMAGE      NPIX      MEAN    STDDEV       MIN       MAX
    #  >             dev$pix    262144     108.3     131.3       -1.    19936.
    #  >
    #  >PANIC in `/scisoft/share/iraf/iraf/bin.redhat/x_images.e': Memory has
    #  >been corrupted
    #  >Killing IRAF task `imstatistics'
    #  >Traceback (innermost last):
    #  > File "<CL script CL1>", line 1, in ?
    #  >   iraf.imstat('dev$pix', _save=1)
    #  >IrafError: Error running IRAF task imstatistics
    #  >('Not a legal IRAF pipe record', 32, 'Broken pipe')
    #  >--> .exit
    #  >
    #  >which is very strange, as this is exactly the same IRAF (as far as I
    #  >can see) to the one I get from the CL.
    #  >
    #  >I half suspect this is an environment rather than fundamental problem,
    #  >but don't know where to look.
    #  >
    #  >Any ideas?
    #  >
    #  >Cheers, Richard
    #
    #  The error you report appears similar to one that Nadia recognized for
    #  another help call.  It is a known IRAF problem on some platforms with
    #  the solution being to add the following line to your ~/.login file (or
    #  whatever unix login file serves the same purpose):
    #  
    #  limit stacksize unlimited
    #  
    #  This should correct the problem.  In the meantime, I hope it cools off
    #  for you soon, or at the very least, that the humidity moves out.
    #  
    #  Cheers,
    #  Warren
    ulimit -s unlimited

fi

#
#  IDL related definitions
#

if [ -d /scisoft/share/idl ]; then
    #  Marco Lombardi sorted out Harald Kuntschner's problem with
    #  strsplit() which was because libraries in /scisoft/share/idl/idl/lib
    #  are not included in IDL_PATH. Actually, rather than including a long
    #  list of specific subdirectories of this, then we just include the whole
    #  tree.

    if [ -f /scisoft/share/idl/idl/bin/idl_setup.bash ]; then
       source /scisoft/share/idl/idl/bin/idl_setup.bash
    fi 

    NEED_TO_EXPORT=false
    for IDLPKG in coyote astron jhuapl starfinder atv; do
        if [ -d /scisoft/share/idl/$IDLPKG ]; then
            if [ -z "$IDL_PATH" ]; then
                IDL_PATH="<IDL_DEFAULT>"
            fi
            IDL_PATH="$IDL_PATH:+/scisoft/share/idl/$IDLPKG"
            NEED_TO_EXPORT=true
        fi
    done
    ! $NEED_TO_EXPORT || export IDL_PATH
    unset NEED_TO_EXPORT

    NEED_TO_EXPORT=false
    for IDLDIR in /scisoft/share/idl/idl; do
        if [ -d $IDLDIR ]; then
            IDL_DIR=/scisoft/share/idl/idl
            NEED_TO_EXPORT=true
        fi
    done
    ! $NEED_TO_EXPORT || export IDL_DIR
    unset NEED_TO_EXPORT
  
    #  Marco wants some settings related to the display for ESO only.
    if [ -f /scisoft/share/idl/startup-eso.idl ]; then
        export IDL_STARTUP=/scisoft/share/idl/startup-eso.idl
    fi

    for BROWSER in firefox google-chrome konqueror; do
        if command -v $BROWSER > /dev/null; then
            export IDL_HELP_BROWSER=$BROWSER
            break
        fi
    done
fi

#
#  Eclipse
#

if  [ -f /scisoft/bin/eclipse ]; then
    export E_PATH=/scisoft
    export E_VERBOSE=1
    export E_MAXMEM=64
    export E_MAXSWAP=128
    export E_TMPDIR=.
    unset E_DEBUG
fi

#
#  Tiny Tim HST psf software
#

if [ -d /scisoft/share/tinytim ]; then
    export TINYTIM=/scisoft/share/tinytim
fi

#
#  PGPLOT graphics software
#

export PGPLOT_DIR=/usr/libexec/pgplot
export PGPLOT_FONT=/usr/share/pgplot/grfont.dat
export PGPLOT_DEV=/xwin

#
#  MIDAS
#

if [ -d /scisoft/share/midas ]; then
  export MIDASHOME=/scisoft/share/midas
  export MIDVERS=`basename $MIDASHOME/*`
  export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$MIDASHOME/$MIDVERS/lib
fi

#
#  XPA - disable warning at startup
#

export XPA_VERSIONCHECK=0

#
# Karma
#

if [ -f /scisoft/share/karma/.karmarc ]; then
    . /scisoft/share/karma/.karmarc
fi
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/scisoft/share/karma/lib/

#
# Gaia
#

export GAIA_DIR=/scisoft/share/star/bin/gaia
export ESP_DIR=/scisoft/share/star/bin/esp
export EXTRACTOR_DIR=/scisoft/share/star/bin/extractor
export CONVERT_DIR=/scisoft/share/star/bin/convert
export KAPPA_DIR=/scisoft/share/star/bin/kappa
export PHOTOM_DIR=/scisoft/share/star/bin/photom
export POLPACK_DIR=/scisoft/share/star/bin/polpack

#
# Theli
#

if [ -f /scisoft/share/theli/theli/pipesetup/pipe_env.bash.Linux ]; then
    . /scisoft/share/theli/theli/pipesetup/pipe_env.bash.Linux
fi

#
# Check if SELinux is enabled
#

if [ -z "$SCISOFT_IGNORE_SELINUX_WARNING" ]; then
    if [ ! -e /usr/sbin/sestatus ]; then
        return
    fi

    if /usr/sbin/sestatus | grep enabled ; then

        echo_if_tty "Warning: SELinux is currently enabled on your computer."
        echo_if_tty "This will prevent some of Scisoft's software such as PyRAF from running."
        echo_if_tty "More information is avaiable in the Scisoft FAQ:"
        echo_if_tty "http://www.eso.org/sci/software/scisoft/faq.html#q25"
        echo_if_tty ""
        echo_if_tty "This warning can be disabled by setting the environment variable SCISOFT_IGNORE_SELINUX_WARNING to '1'"
    fi
fi
